PREMADE_REPORTS = [
    {
        "name": "user_acq_first_user_default_channel_group_report",
        "metrics": [
            "newUsers",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "firstUserDefaultChannelGroup",
        ],
    },
    {
        "name": "user_acq_first_user_medium_report",
        "metrics": [
            "newUsers",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "firstUserMedium",
        ],
    },
    {
        "name": "user_acq_first_user_source_report",
        "metrics": [
            "newUsers",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "firstUserSource",
        ],
    },
    {
        "name": "user_acq_first_user_source_and_medium_report",
        "metrics": [
            "newUsers",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "firstUserSourceMedium",
        ],
    },
    {
        "name": "user_acq_first_user_source_platform_report",
        "metrics": [
            "newUsers",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
            ],
        "dimensions": [
            "date",
            "firstUserSourcePlatform",
        ],
    },
    {
        "name": "user_acq_first_user_campaign_report",
        "metrics": [
            "newUsers",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "firstUserCampaignName",
        ],
    },
    {
        "name": "user_acq_first_user_google_ads_network_type_report",
        "metrics": [
            "newUsers",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "firstUserGoogleAdsAdNetworkType",
        ],
    },
    {
        "name": "user_acq_first_user_google_ads_ad_group_name_report",
        "metrics": [
            "newUsers",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "firstUserGoogleAdsAdGroupName",
        ],
    },
    {
        "name": "traffic_acq_session_source_and_medium_report",
        "metrics": [
            "totalUsers",
            "sessions",
            "engagedSessions",
            "eventsPerSession",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "sessionSourceMedium",
        ],
    },
    {
        "name": "traffic_acq_session_medium_report",
        "metrics": [
            "totalUsers",
            "sessions",
            "engagedSessions",
            "eventsPerSession",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "sessionMedium",
        ],
    },
    {
        "name": "traffic_acq_session_source_report",
        "metrics": [
            "totalUsers",
            "sessions",
            "engagedSessions",
            "eventsPerSession",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "sessionSource",
        ],
    },
    {
        "name": "traffic_acq_session_campaign_report",
        "metrics": [
            "totalUsers",
            "sessions",
            "engagedSessions",
            "eventsPerSession",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "sessionCampaignName",
        ],
    },
    {
        "name": "traffic_acq_session_default_channel_group_report",
        "metrics": [
            "totalUsers",
            "sessions",
            "engagedSessions",
            "eventsPerSession",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "sessionDefaultChannelGroup",
        ],
    },
    {
        "name": "traffic_acq_session_source_platform_report",
        "metrics": [
            "totalUsers",
            "sessions",
            "engagedSessions",
            "eventsPerSession",
            "engagementRate",
            "eventCount",
            "conversions",
            "totalRevenue",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "sessionSourcePlatform",
        ],
    },
    {
        "name": "events_report",
        "metrics": [
            "eventCount",
            "totalUsers",
            "eventCountPerUser",
            "totalRevenue",
        ],
        "dimensions": [
            "date",
            "eventName",
        ],
    },
    {
        "name": "conversions_report",
        "metrics": [
            "conversions",
            "totalUsers",
            "totalRevenue",
        ],
        "dimensions": [
            "date",
            "eventName",
        ],
    },
    {
        "name": "page_title_and_screen_class_report",
        "metrics": [
            "screenPageViews",
            "totalUsers",
            "newUsers",
            "eventCount",
            "conversions",
            "totalRevenue",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "unifiedScreenClass",
        ],
    },
    {
        "name": "page_path_and_screen_class_report",
        "metrics": [
            "screenPageViews",
            "totalUsers",
            "newUsers",
            "eventCount",
            "conversions",
            "totalRevenue",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "unifiedPagePathScreen",
        ],
    },
    {
        "name": "page_title_and_screen_name_report",
        "metrics": [
            "screenPageViews",
            "totalUsers",
            "newUsers",
            "eventCount",
            "conversions",
            "totalRevenue",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "unifiedScreenName",
        ],
    },
    {
        "name": "content_group_report",
        "metrics": [
            "screenPageViews",
            "totalUsers",
            "newUsers",
            "eventCount",
            "conversions",
            "totalRevenue",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "contentGroup",
        ],
    },
    {
        "name": "ecommerce_purchases_item_name_report",
        "metrics": [
            "addToCarts",
            "cartToViewRate",
            "ecommercePurchases",
            "itemPurchaseQuantity",
            "itemRevenue",
            "itemViews",
            "purchaseToViewRate",
        ],
        "dimensions": [
            "date",
            "itemName",
        ],
    },
    {
        "name": "ecommerce_purchases_item_id_report",
        "metrics": [
            "addToCarts",
            "cartToViewRate",
            "ecommercePurchases",
            "itemPurchaseQuantity",
            "itemRevenue",
            "itemViews",
            "purchaseToViewRate",
        ],
        "dimensions": [
            "date",
            "itemId",
        ],
    },
    {
        "name": "ecommerce_purchases_item_category_report",
        "metrics": [
            "addToCarts",
            "cartToViewRate",
            "ecommercePurchases",
            "itemPurchaseQuantity",
            "itemRevenue",
            "itemViews",
            "purchaseToViewRate",
        ],
        "dimensions": [
            "date",
            "itemCategory",
        ],
    },
    {
        "name": "ecommerce_purchases_item_category_2_report",
        "metrics": [
            "addToCarts",
            "cartToViewRate",
            "ecommercePurchases",
            "itemPurchaseQuantity",
            "itemRevenue",
            "itemViews",
            "purchaseToViewRate",
        ],
        "dimensions": [
            "date",
            "itemCategory2",
        ],
    },
    {
        "name": "ecommerce_purchases_item_category_3_report",
        "metrics": [
            "addToCarts",
            "cartToViewRate",
            "ecommercePurchases",
            "itemPurchaseQuantity",
            "itemRevenue",
            "itemViews",
            "purchaseToViewRate",
        ],
        "dimensions": [
            "date",
            "itemCategory3",
        ],
    },
    {
        "name": "ecommerce_purchases_item_category_4_report",
        "metrics": [
            "addToCarts",
            "cartToViewRate",
            "ecommercePurchases",
            "itemPurchaseQuantity",
            "itemRevenue",
            "itemViews",
            "purchaseToViewRate",
        ],
        "dimensions": [
            "date",
            "itemCategory4",
        ],
    },
    {
        "name": "ecommerce_purchases_item_category_5_report",
        "metrics": [
            "addToCarts",
            "cartToViewRate",
            "ecommercePurchases",
            "itemPurchaseQuantity",
            "itemRevenue",
            "itemViews",
            "purchaseToViewRate",
        ],
        "dimensions": [
            "date",
            "itemCategory5",
        ],
    },
    {
        "name": "ecommerce_purchases_item_brand_report",
        "metrics": [
            "addToCarts",
            "cartToViewRate",
            "ecommercePurchases",
            "itemPurchaseQuantity",
            "itemRevenue",
            "itemViews",
            "purchaseToViewRate",
        ],
        "dimensions": [
            "date",
            "itemBrand",
        ],
    },
    {
        "name": "in_app_purchases",
        "metrics": [
            "itemsPurchased",
            "itemRevenue",
        ],
        "dimensions": [
            "date",
            "itemId",
        ],
    },
    {
        "name": "publisher_ads_ad_unit_report",
        "metrics": [
            "adUnitExposure",
            "publisherAdClicks",
            "publisherAdImpressions",
            "totalAdRevenue",
        ],
        "dimensions": [
            "date",
            "adUnitName",
        ],
    },
    {
        "name": "publisher_ads_page_path_report",
        "metrics": [
            "adUnitExposure",
            "publisherAdClicks",
            "publisherAdImpressions",
            "totalAdRevenue",
        ],
        "dimensions": [
            "date",
            "unifiedPagePathScreen",
        ],
    },
    {
        "name": "publisher_ads_ad_format_report",
        "metrics": [
            "adUnitExposure",
            "publisherAdClicks",
            "publisherAdImpressions",
            "totalAdRevenue",
        ],
        "dimensions": [
            "date",
            "adFormat",
        ],
    },
    {
        "name": "publisher_ads_ad_source_report",
        "metrics": [
            "adUnitExposure",
            "publisherAdClicks",
            "publisherAdImpressions",
            "totalAdRevenue",
        ],
        "dimensions": [
            "date",
            "adSourceName",
        ],
    },
    {
        "name": "demographic_country_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount"
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "country",
        ],
    },
    {
        "name": "demographic_region_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "region",
        ],
    },
    {
        "name": "demographic_city_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "city",
        ],
    },
    {
        "name": "demographic_language_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "language",
        ],
    },
    {
        "name": "demographic_age_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "userAgeBracket",
        ],
    },
    {
        "name": "demographic_gender_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "userGender",
        ],
    },
    {
        "name": "demographic_interests_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "brandingInterest",
        ],
    },
    {
        "name": "tech_browser_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "browser",
        ],
    },
    {
        "name": "tech_device_category_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "deviceCategory",
        ],
    },
    {
        "name": "tech_device_model_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "deviceModel",
        ],
    },
    {
        "name": "tech_screen_resolution_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "screenResolution",
        ],
    },
    {
        "name": "tech_app_version_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "appVersion",
        ],
    },
    {
        "name": "tech_platform_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "platform",
        ],
    },
        {
        "name": "tech_os_version_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "operatingSystemVersion",
        ],
    },
    {
        "name": "tech_platform_and_device_category_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "platformDeviceCatetory",
        ],
    },
    {
        "name": "tech_operating_system_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "operatingSystem"
        ],
    },
    {
        "name": "tech_os_with_version_report",
        "metrics": [
            "conversions",
            "engagedSessions",
            "engagementRate",
            "eventCount",
            "newUsers",
            "totalRevenue",
            "totalUsers",
            "userEngagementDuration",
        ],
        "dimensions": [
            "date",
            "operatingSystemWithVersion",
            ],
    },
]
